#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%define soname 1
%define libsuffix %(echo %{_lib}|%__sed 's/^lib//')
Name:           Collage
Version:        1.0.0
Release:        2.1
Summary:        Object-Oriented C++ Network Library: Applications 
Group:          Productivity/Networking/Other
License:        LGPL-2.1
URL:            http://www.equalizergraphics.com/
Source0:        %{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE DoxygenRule.diff avvissu@yandex.ru -- Creates a files or folders in the root directory
Patch0:         DoxygenRule.diff
# PATCH-FIX-OPENSUSE fix-64bit.diff avvissu@yandex.ru -- Patch to fix the libdir on 64-bit architecture
Patch1:         fix-64bit.diff
# PATCH-FIX-OPENSUSE date-and-time.diff avvissu@yandex.ru -- Do not compile in DATE and TIME
Patch2:         date-and-time.diff
# PATCH-FIX-OPENSUSE sub_test.patch -- #include <queue> pick up the test binary instead of std::queue
Patch3:         sub_test.patch
BuildRequires:  gcc-c++ cmake pkg-config 
BuildRequires:  glew-devel Lunchbox-devel
BuildRequires:  doxygen graphviz
%ifarch %ix86 x86_64
BuildRequires:  udt-devel 
%endif
BuildRequires:  fdupes 
###OFED support###
 %if 0%{?suse_version} > 1310
BuildRequires:  libibverbs-devel librdmacm-devel
%endif
BuildRoot:     %{_tmppath}/build-%{name}-%{version} 

%description
Cross-platform C++ library for building heterogenous,
distributed applications. It is used as the cluster backend for the
Equalizer parallel rendering framework. Collage provides an abstraction
of different network connections, peer-to-peer messaging, discovery and
synchronization as well as high-performance, object-oriented, versioned
data distribution. Collage is designed for low-overhead multi-threaded
execution which allows applications to easily exploit multi-core
architectures.


%package -n     lib%{name}%{soname}
Summary:        Object-Oriented C++ Network Library
Group:          System/Libraries
License:        LGPL-2.1

%description -n lib%{name}%{soname}
Cross-platform C++ library for building heterogenous,
distributed applications. It is used as the cluster backend for the
Equalizer parallel rendering framework. Collage provides an abstraction
of different network connections, peer-to-peer messaging, discovery and
synchronization as well as high-performance, object-oriented, versioned
data distribution. Collage is designed for low-overhead multi-threaded
execution which allows applications to easily exploit multi-core
architectures.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
License:        LGPL-2.1
Requires:       lib%{name}%{soname} = %{version}-%{release}
Requires:       pkg-config Lunchbox-devel 
%ifarch %ix86 x86_64
Requires:       udt-devel
%endif

%description devel
This package contains, header files, and libraries needed to
develop application that use %{name}

%package doc
Summary:	    Documentation for %{name}
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
API Documentation for %{name}.

%prep
%setup -q  
%patch0
%patch1
%patch2 -p1
%patch3 -p1

%build
cmake  \
      -DLIB_SUFFIX="%{libsuffix}" \
      -DCMAKE_BUILD_TYPE=release \
      -DCMAKE_CXX_FLAGS_RELEASE:STRING="%{optflags}"
     
make %{?_smp_mflags}
make %{?_smp_mflags} doxygen

%install
make install DESTDIR=%{buildroot}
mkdir -p %{buildroot}%{_docdir}/lib%{name}%{soname}
mv %{buildroot}{%_datadir/%name/doc/*,%_docdir/lib%name%soname}

%fdupes -s %{buildroot}%{_docdir}/lib%{name}%{soname}

#%check
#make test

%clean  
rm -rf %{buildroot}  

%post -n lib%{name}%{soname} -p /sbin/ldconfig  
%postun -n lib%{name}%{soname} -p /sbin/ldconfig  

%files 
%defattr(-,root,root)
%{_bindir}/coNetperf
%{_bindir}/coNodeperf

%files -n lib%{name}%{soname}
%defattr(-,root,root) 
%{_docdir}/lib%{name}%{soname}
%{_libdir}/libCollage*.so.*
%exclude %{_docdir}/lib%{name}%{soname}/API

%files devel
%defattr(-,root,root) 
%{_includedir}/co
%{_libdir}/libCollage*.so
%{_libdir}/pkgconfig/%{name}.pc
%dir %{_datadir}/%{name}
#%dir %{_datadir}/%{name}/tests
#%{_datadir}/%{name}/tests/*.cpp
%dir %{_datadir}/%{name}/CMake
%{_datadir}/%{name}/CMake/*.cmake

%files doc
%defattr(-,root,root) 
%{_docdir}/lib%{name}%{soname}/API

%changelog
* Sun Oct 12 2014 avvissu@yandex.ru
- add OFED support on openSUSE > 13.1:
  * add RPM test suse_version
* Wed Sep 17 2014 avvissu@yandex.ru
- [Fixed] RPMlint W: Your file uses  __DATE and __TIME__ this
  causes the package to rebuild when not needed
* Wed Dec 25 2013 avvissu@yandex.ru
- add UDP-based Data Transfer Protocol
* Fri Dec 20 2013 avvissu@yandex.ru
- Initial release
